# Bugsink

Bugsink offers real-time error tracking for your applications with full control
through self-hosting. Easily install on your servers, connect any app using
Sentry-compatible SDKs, and rely on scalable performance to handle millions of
events daily without failure. Get all the details you need in one place to
quickly triage and fix errors.

https://www.bugsink.com/
